/**
 * tdesign v1.8.5
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var badge_index = require('../badge/index.js');
var image_index = require('../image/index.js');
var config = require('../config.js');
var avatar_props = require('./props.js');
var hooks_tnode = require('../hooks/tnode.js');
var hooks_useClass = require('../hooks/useClass.js');
var _common_js_avatar_utils = require('../_common/js/avatar/utils.js');
require('../badge/badge.js');
require('@babel/runtime/helpers/slicedToArray');
require('@babel/runtime/helpers/defineProperty');
require('../badge/props.js');
require('../_chunks/dep-e031babb.js');
require('../_chunks/dep-e359cf98.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-0334b2f1.js');
require('../_chunks/dep-d8882efd.js');
require('../_chunks/dep-5bd74ffa.js');
require('../shared/component.js');
require('../_chunks/dep-e718c228.js');
require('../_chunks/dep-e1c0f7fe.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-2934441b.js');
require('../_chunks/dep-3a644805.js');
require('dayjs');
require('../_chunks/dep-5029e827.js');
require('../_chunks/dep-cfb0e78f.js');
require('../_chunks/dep-31fe6b59.js');
require('../_chunks/dep-e2cd1076.js');
require('../_chunks/dep-333f1d82.js');
require('../_chunks/dep-6b61da52.js');
require('../_chunks/dep-142e416b.js');
require('../_chunks/dep-1a60658f.js');
require('../_chunks/dep-6aef49c4.js');
require('../_chunks/dep-9141aa78.js');
require('../_chunks/dep-2c83a65b.js');
require('../_chunks/dep-d57d3ed5.js');
require('../_chunks/dep-8aaa430c.js');
require('../_chunks/dep-54b872a8.js');
require('../_chunks/dep-402efc35.js');
require('../_chunks/dep-2793a292.js');
require('../_chunks/dep-9bef960e.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-0484d708.js');
require('../_chunks/dep-45a683b0.js');
require('../_chunks/dep-f01c346c.js');
require('../_chunks/dep-9289591a.js');
require('../_chunks/dep-f4556ad8.js');
require('../_chunks/dep-b4897936.js');
require('../_chunks/dep-db2c642e.js');
require('../_chunks/dep-86f56bd7.js');
require('../image/image.js');
require('@vueuse/core');
require('tdesign-icons-vue-next');
require('../loading/index.js');
require('../loading/loading.js');
require('../loading/icon/gradient.js');
require('../_common/js/loading/circle-adapter.js');
require('../_common/js/utils/setStyle.js');
require('../_common/js/utils/helper.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../_chunks/dep-88147c3c.js');
require('../_chunks/dep-ee1322e3.js');
require('../loading/icon/spinner.js');
require('../loading/props.js');
require('../shared/dom.js');
require('../loading/plugin.js');
require('../image/props.js');

var prefix = config["default"].prefix;
var _Avatar = vue.defineComponent({
  name: "".concat(prefix, "-avatar"),
  props: avatar_props["default"],
  setup: function setup(props) {
    var renderTNodeJSX = hooks_tnode.useTNodeJSX();
    var renderTNodeContent = hooks_tnode.useContent();
    var avatarClass = hooks_useClass.usePrefixClass("avatar");
    var avatarGroupProps = vue.inject("avatarGroup", {});
    var hasAvatarGroupProps = Object.keys(avatarGroupProps).length > 0;
    var shapeValue = vue.computed(function () {
      return props.shape || (avatarGroupProps === null || avatarGroupProps === void 0 ? void 0 : avatarGroupProps.shape) || "circle";
    });
    var sizeValue = vue.computed(function () {
      return props.size || (avatarGroupProps === null || avatarGroupProps === void 0 ? void 0 : avatarGroupProps.size);
    });
    var isCustomSize = vue.computed(function () {
      return !_common_js_avatar_utils.isValidSize(sizeValue.value);
    });
    var avatarClasses = vue.computed(function () {
      return ["".concat(avatarClass.value), "".concat(avatarClass.value, "--").concat(isCustomSize.value ? "medium" : sizeValue.value), "".concat(avatarClass.value, "--").concat(shapeValue.value), hasAvatarGroupProps ? "".concat(avatarClass.value, "--border ").concat(avatarClass.value, "--border-").concat(isCustomSize.value ? "medium" : sizeValue.value) : ""];
    });
    var customSize = vue.computed(function () {
      return isCustomSize.value ? {
        height: sizeValue.value,
        width: sizeValue.value,
        "font-size": "".concat(Number.parseInt(sizeValue.value, 10) / 8 * 3 + 2, "px")
      } : {};
    });
    var handleImgLoadError = function handleImgLoadError(e) {
      var _props$onError;
      (_props$onError = props.onError) === null || _props$onError === void 0 || _props$onError.call(props, e);
    };
    return function () {
      var icon = renderTNodeJSX("icon");
      var TNodeContent = renderTNodeContent("default", "content");
      var readerAvatar = function readerAvatar() {
        if (props.image && !props.hideOnLoadFailed) {
          return vue.createVNode(image_index.Image, vue.mergeProps({
            "src": props.image,
            "alt": props.alt
          }, props.imageProps, {
            "onError": handleImgLoadError
          }), null);
        }
        if (icon) {
          return vue.createVNode("div", {
            "class": "".concat(avatarClass.value, "__icon")
          }, [icon]);
        }
        return vue.createVNode(vue.Fragment, null, [TNodeContent]);
      };
      return vue.createVNode("div", {
        "class": "".concat(avatarClass.value, "__wrapper")
      }, [vue.createVNode("div", {
        "class": "".concat(avatarClass.value, "__badge")
      }, [vue.createVNode(badge_index.Badge, props.badgeProps, {
        default: function _default() {
          return [vue.createVNode("div", {
            "class": avatarClasses.value,
            "style": customSize.value
          }, [readerAvatar()])];
        }
      })])]);
    };
  }
});

exports["default"] = _Avatar;
//# sourceMappingURL=avatar.js.map
