/**
 * tdesign v1.8.5
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var vue = require('vue');
var tdesignIconsVueNext = require('tdesign-icons-vue-next');
var hooks_useClass = require('../hooks/useClass.js');
var hooks_tnode = require('../hooks/tnode.js');
var progress_utils = require('./utils.js');
var progress_props = require('./props.js');
var _common_js_progress_const = require('../_common/js/progress/const.js');
var _common_js_progress_utils = require('../_common/js/progress/utils.js');
var config = require('../config.js');
var isString = require('../_chunks/dep-e031babb.js');
var isObject = require('../_chunks/dep-6b61da52.js');
require('../_chunks/dep-e718c228.js');
require('../_chunks/dep-e1c0f7fe.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-2934441b.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-3a644805.js');
require('dayjs');
require('../_chunks/dep-5029e827.js');
require('../_chunks/dep-cfb0e78f.js');
require('../_chunks/dep-31fe6b59.js');
require('../_chunks/dep-e2cd1076.js');
require('../_chunks/dep-333f1d82.js');
require('../_chunks/dep-e359cf98.js');
require('../_chunks/dep-142e416b.js');
require('../_chunks/dep-1a60658f.js');
require('../_chunks/dep-d8882efd.js');
require('../_chunks/dep-6aef49c4.js');
require('../_chunks/dep-9141aa78.js');
require('../_chunks/dep-0334b2f1.js');
require('../_chunks/dep-2c83a65b.js');
require('../_chunks/dep-d57d3ed5.js');
require('../_chunks/dep-8aaa430c.js');
require('../_chunks/dep-54b872a8.js');
require('../_chunks/dep-402efc35.js');
require('../_chunks/dep-2793a292.js');
require('../_chunks/dep-9bef960e.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-0484d708.js');
require('../_chunks/dep-45a683b0.js');
require('../_chunks/dep-f01c346c.js');
require('../_chunks/dep-9289591a.js');
require('../_chunks/dep-f4556ad8.js');
require('../_chunks/dep-b4897936.js');
require('../_chunks/dep-db2c642e.js');
require('../_chunks/dep-86f56bd7.js');
require('@babel/runtime/helpers/objectWithoutProperties');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

var prefix = config["default"].prefix;
var _Progress = vue.defineComponent({
  name: "".concat(prefix, "-progress"),
  props: progress_props["default"],
  setup: function setup(props2) {
    var renderTNodeJSX = hooks_tnode.useTNodeJSX();
    var progressClass = hooks_useClass.usePrefixClass("progress");
    var computedStatus = vue.computed(function () {
      if (props2.percentage >= 100) {
        return "success";
      }
      return props2.status || "default";
    });
    var trackBgStyle = vue.computed(function () {
      var style = {};
      if (props2.strokeWidth) {
        var height = isString.isString(props2.strokeWidth) ? props2.strokeWidth : "".concat(props2.strokeWidth, "px");
        style.height = height;
        style.borderRadius = height;
      }
      if (props2.trackColor) {
        style.backgroundColor = props2.trackColor;
      }
      return style;
    });
    var barStyle = vue.computed(function () {
      return {
        width: "".concat(props2.percentage, "%"),
        background: props2.color && progress_utils.getBackgroundColor(props2.color)
      };
    });
    var getIconMap = function getIconMap() {
      var CIRCLE_ICONS = {
        success: tdesignIconsVueNext.CheckIcon,
        warning: tdesignIconsVueNext.ErrorIcon,
        error: tdesignIconsVueNext.CloseIcon
      };
      var NORMAL_ICONS = {
        success: tdesignIconsVueNext.CheckCircleFilledIcon,
        warning: tdesignIconsVueNext.ErrorCircleFilledIcon,
        error: tdesignIconsVueNext.ErrorCircleFilledIcon
      };
      return props2.theme === _common_js_progress_const.PRO_THEME.CIRCLE ? CIRCLE_ICONS : NORMAL_ICONS;
    };
    var diameter = vue.computed(function () {
      return _common_js_progress_utils.getDiameter(props2.size);
    });
    var rPoints = vue.computed(function () {
      return diameter.value / 2;
    });
    var circleStrokeWidth = vue.computed(function () {
      return _common_js_progress_utils.getCircleStokeWidth(props2.strokeWidth, props2.size);
    });
    var radius = vue.computed(function () {
      return rPoints.value - circleStrokeWidth.value / 2;
    });
    var circleStyle = vue.computed(function () {
      if (props2.theme !== _common_js_progress_const.PRO_THEME.CIRCLE) {
        return {};
      }
      return {
        width: "".concat(diameter.value, "px"),
        height: "".concat(diameter.value, "px")
      };
    });
    var strokeDashArr = vue.computed(function () {
      var radius2 = (diameter.value - circleStrokeWidth.value) / 2;
      var perimeter = Math.PI * 2 * radius2;
      var percent = props2.percentage / 100;
      return "".concat(perimeter * percent, "  ").concat(perimeter * (1 - percent));
    });
    var circlePathStyle = vue.computed(function () {
      var strokeColor = isObject.isObject(props2.color) ? "" : props2.color;
      return {
        stroke: strokeColor
      };
    });
    var circleOuterStyle = vue.computed(function () {
      var strokeColor = isObject.isObject(props2.trackColor) ? "" : props2.trackColor;
      return {
        stroke: strokeColor
      };
    });
    var getLabelContent = function getLabelContent() {
      var labelContent = "".concat(props2.percentage, "%");
      var status = props2.status || "";
      if (_common_js_progress_const.STATUS_ICON.includes(status) && props2.theme !== _common_js_progress_const.PRO_THEME.PLUMP) {
        var components = getIconMap();
        var component = components[status];
        if (component) {
          labelContent = vue.createVNode(component, {
            "class": ["".concat(progressClass.value, "__icon")]
          }, null);
        }
      }
      return labelContent;
    };
    return function () {
      var labelContent = props2.label && vue.createVNode("div", {
        "class": "".concat(progressClass.value, "__info")
      }, [renderTNodeJSX("label", getLabelContent())]);
      var separateClasses = props2.percentage > _common_js_progress_const.PLUMP_SEPARATE ? "".concat(progressClass.value, "--over-ten") : "".concat(progressClass.value, "--under-ten");
      return vue.createVNode("div", {
        "class": progressClass.value
      }, [props2.theme === _common_js_progress_const.PRO_THEME.LINE && vue.createVNode("div", {
        "class": "".concat(progressClass.value, "--thin ").concat(progressClass.value, "--status-").concat(computedStatus.value)
      }, [vue.createVNode("div", {
        "class": "".concat(progressClass.value, "__bar"),
        "style": trackBgStyle.value
      }, [vue.createVNode("div", {
        "class": "".concat(progressClass.value, "__inner"),
        "style": barStyle.value
      }, null)]), labelContent]), props2.theme === _common_js_progress_const.PRO_THEME.PLUMP && vue.createVNode("div", {
        "class": ["".concat(progressClass.value, "__bar ").concat(progressClass.value, "--plump ").concat(separateClasses), _defineProperty__default["default"]({}, "".concat(progressClass.value, "--status-").concat(computedStatus.value), computedStatus.value)],
        "style": trackBgStyle.value
      }, [vue.createVNode("div", {
        "class": "".concat(progressClass.value, "__inner"),
        "style": barStyle.value
      }, [props2.percentage > _common_js_progress_const.PLUMP_SEPARATE && labelContent]), props2.percentage <= _common_js_progress_const.PLUMP_SEPARATE && labelContent]), props2.theme === _common_js_progress_const.PRO_THEME.CIRCLE && vue.createVNode("div", {
        "class": "".concat(progressClass.value, "--circle ").concat(progressClass.value, "--status-").concat(computedStatus.value),
        "style": circleStyle.value
      }, [labelContent, vue.createVNode("svg", {
        "width": diameter.value,
        "height": diameter.value,
        "viewBox": "0 0 ".concat(diameter.value, " ").concat(diameter.value)
      }, [vue.createVNode("circle", {
        "cx": rPoints.value,
        "cy": rPoints.value,
        "r": radius.value,
        "stroke-width": circleStrokeWidth.value,
        "fill": "none",
        "class": ["".concat(progressClass.value, "__circle-outer")],
        "style": circleOuterStyle.value
      }, null), props2.percentage > 0 && vue.createVNode("circle", {
        "cx": rPoints.value,
        "cy": rPoints.value,
        "r": radius.value,
        "stroke-width": circleStrokeWidth.value,
        "fill": "none",
        "stroke-linecap": "round",
        "class": ["".concat(progressClass.value, "__circle-inner")],
        "transform": "matrix(0,-1,1,0,0,".concat(diameter.value, ")"),
        "stroke-dasharray": strokeDashArr.value,
        "style": circlePathStyle.value
      }, null)])])]);
    };
  }
});

exports["default"] = _Progress;
//# sourceMappingURL=progress.js.map
