/**
 * tdesign v1.8.5
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var vue = require('vue');
var tdesignIconsVueNext = require('tdesign-icons-vue-next');
var config = require('../config.js');
var stepper_props = require('./props.js');
var form_hooks = require('../form/hooks.js');
var hooks_useVModel = require('../hooks/useVModel.js');
var hooks_useClass = require('../hooks/useClass.js');
var shared_util = require('../shared/util.js');
require('../_chunks/dep-c7596cb6.js');
require('../_chunks/dep-e359cf98.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-d8882efd.js');
require('../_chunks/dep-db2c642e.js');
require('../_chunks/dep-b4897936.js');
require('../_chunks/dep-45a683b0.js');
require('../_chunks/dep-f01c346c.js');
require('../_chunks/dep-0334b2f1.js');
require('../_chunks/dep-9289591a.js');
require('../_chunks/dep-e718c228.js');
require('@babel/runtime/helpers/defineProperty');
require('../_chunks/dep-e1c0f7fe.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-2934441b.js');
require('../_chunks/dep-3a644805.js');
require('dayjs');
require('../_chunks/dep-5029e827.js');
require('../_chunks/dep-cfb0e78f.js');
require('../_chunks/dep-31fe6b59.js');
require('../_chunks/dep-e2cd1076.js');
require('../_chunks/dep-333f1d82.js');
require('../_chunks/dep-6b61da52.js');
require('../_chunks/dep-142e416b.js');
require('../_chunks/dep-1a60658f.js');
require('../_chunks/dep-6aef49c4.js');
require('../_chunks/dep-9141aa78.js');
require('../_chunks/dep-2c83a65b.js');
require('../_chunks/dep-d57d3ed5.js');
require('../_chunks/dep-8aaa430c.js');
require('../_chunks/dep-54b872a8.js');
require('../_chunks/dep-402efc35.js');
require('../_chunks/dep-2793a292.js');
require('../_chunks/dep-9bef960e.js');
require('../_chunks/dep-e031babb.js');
require('../_chunks/dep-5bd74ffa.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _slicedToArray__default = /*#__PURE__*/_interopDefaultLegacy(_slicedToArray);

var prefix = config["default"].prefix;
var _Stepper = vue.defineComponent({
  name: "".concat(prefix, "-stepper"),
  props: stepper_props["default"],
  setup: function setup(props2, context) {
    var stepperClass = hooks_useClass.usePrefixClass("stepper");
    var _toRefs = vue.toRefs(props2),
      value = _toRefs.value,
      modelValue = _toRefs.modelValue,
      min = _toRefs.min,
      max = _toRefs.max,
      step = _toRefs.step,
      integer = _toRefs.integer;
    var _useVModel = hooks_useVModel["default"](value, modelValue, props2.defaultValue, props2.onChange),
      _useVModel2 = _slicedToArray__default["default"](_useVModel, 2),
      stepperValue = _useVModel2[0],
      setStepperValue = _useVModel2[1];
    var disabled = form_hooks.useFormDisabled();
    var inputStyle = vue.computed(function () {
      return props2.inputWidth ? {
        width: "".concat(props2.inputWidth, "px")
      } : "";
    });
    var isDisabled = function isDisabled(type) {
      if (disabled.value) return true;
      if (type === "minus" && Number(stepperValue.value) <= min.value) {
        return true;
      }
      if (type === "plus" && Number(stepperValue.value) >= max.value) {
        return true;
      }
      return false;
    };
    var getLen = function getLen(num) {
      var numStr = num.toString();
      return numStr.indexOf(".") === -1 ? 0 : numStr.split(".")[1].length;
    };
    var add = function add(a, b) {
      var maxLen = Math.max(getLen(a), getLen(b));
      var base = Math.pow(10, maxLen);
      return Math.round(a * base + b * base) / base;
    };
    var formatValue = function formatValue(value2) {
      return Math.max(Math.min(max.value, value2, Number.MAX_SAFE_INTEGER), min.value, Number.MIN_SAFE_INTEGER).toFixed(Math.max(getLen(step.value), getLen(value2)));
    };
    var updateValue = function updateValue(value2) {
      setStepperValue(shared_util.formatNumber("".concat(value2), !integer.value));
    };
    var plusValue = function plusValue() {
      if (isDisabled("plus")) {
        var _props2$onOverlimit;
        (_props2$onOverlimit = props2.onOverlimit) === null || _props2$onOverlimit === void 0 || _props2$onOverlimit.call(props2, "plus");
        return;
      }
      updateValue(formatValue(add(Number(stepperValue.value), step.value)));
    };
    var minusValue = function minusValue() {
      if (isDisabled("minus")) {
        var _props2$onOverlimit2;
        (_props2$onOverlimit2 = props2.onOverlimit) === null || _props2$onOverlimit2 === void 0 || _props2$onOverlimit2.call(props2, "minus");
        return;
      }
      updateValue(formatValue(add(Number(stepperValue.value), -step.value)));
    };
    var handleInput = function handleInput(e) {
      var value2 = shared_util.formatNumber(e.target.value, !integer.value);
      setStepperValue(value2);
    };
    var handleChange = function handleChange() {
      var formattedValue = formatValue(Number(stepperValue.value));
      updateValue(formattedValue);
    };
    var handleFocus = function handleFocus() {
      var _props2$onFocus;
      (_props2$onFocus = props2.onFocus) === null || _props2$onFocus === void 0 || _props2$onFocus.call(props2, Number(stepperValue.value));
    };
    var handleBlur = function handleBlur() {
      var _props2$onBlur;
      (_props2$onBlur = props2.onBlur) === null || _props2$onBlur === void 0 || _props2$onBlur.call(props2, Number(stepperValue.value));
    };
    return function () {
      return vue.createVNode("div", {
        "class": ["".concat(stepperClass.value), "".concat(stepperClass.value, "--").concat(props2.size)]
      }, [vue.createVNode("div", {
        "class": ["".concat(stepperClass.value, "__minus"), "".concat(stepperClass.value, "__minus--").concat(props2.theme), "".concat(stepperClass.value, "__icon--").concat(props2.size), "".concat(disabled.value || Number(stepperValue.value) <= props2.min ? "".concat(stepperClass.value, "--").concat(props2.theme, "-disabled") : "")],
        "onClick": minusValue
      }, [vue.createVNode(tdesignIconsVueNext.RemoveIcon, {
        "class": "".concat(stepperClass.value, "__minus-icon")
      }, null)]), vue.createVNode("input", {
        "value": stepperValue.value,
        "class": ["".concat(stepperClass.value, "__input"), "".concat(stepperClass.value, "__input--").concat(props2.theme), "".concat(stepperClass.value, "__input--").concat(props2.size), "".concat(disabled.value ? "".concat(stepperClass.value, "--").concat(props2.theme, "-disabled") : "")],
        "type": integer.value ? "tel" : "text",
        "inputmode": integer.value ? "numeric" : "decimal",
        "style": inputStyle.value,
        "disabled": props2.disableInput || disabled.value,
        "readonly": props2.disableInput,
        "onFocus": handleFocus,
        "onBlur": handleBlur,
        "onInput": handleInput,
        "onChange": handleChange
      }, null), vue.createVNode("div", {
        "class": ["".concat(stepperClass.value, "__plus"), "".concat(stepperClass.value, "__plus--").concat(props2.theme), "".concat(stepperClass.value, "__icon--").concat(props2.size), "".concat(disabled.value || Number(stepperValue.value) >= props2.max ? "".concat(stepperClass.value, "--").concat(props2.theme, "-disabled") : "")],
        "onClick": plusValue
      }, [vue.createVNode(tdesignIconsVueNext.AddIcon, {
        "class": "".concat(stepperClass.value, "__plus-icon")
      }, null)])]);
    };
  }
});

exports["default"] = _Stepper;
//# sourceMappingURL=stepper.js.map
