/**
 * tdesign v1.8.5
 * (c) 2025 TDesign Group
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _typeof = require('@babel/runtime/helpers/typeof');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var vue = require('vue');
var hooks_useLengthLimit = require('../hooks/useLengthLimit.js');
var config = require('../config.js');
var textarea_props = require('./props.js');
var _common_js_utils_calcTextareaHeight = require('../_common/js/utils/calcTextareaHeight.js');
var form_const = require('../form/const.js');
var form_hooks = require('../form/hooks.js');
var hooks_useClass = require('../hooks/useClass.js');
var hooks_tnode = require('../hooks/tnode.js');
var hooks_useVModel = require('../hooks/useVModel.js');
require('../_common/js/log/log.js');
require('../_common/js/utils/helper.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../_chunks/dep-88147c3c.js');
require('../_chunks/dep-ee1322e3.js');
require('../_chunks/dep-e031babb.js');
require('../_chunks/dep-e359cf98.js');
require('../_chunks/dep-0334b2f1.js');
require('../_chunks/dep-d8882efd.js');
require('../_chunks/dep-5bd74ffa.js');
require('../_chunks/dep-6b61da52.js');
require('../_chunks/dep-c7596cb6.js');
require('../_chunks/dep-e718c228.js');
require('../_chunks/dep-e1c0f7fe.js');
require('../_common/js/global-config/mobile/default-config.js');
require('../_common/js/global-config/mobile/locale/zh_CN.js');
require('../_chunks/dep-2934441b.js');
require('../_chunks/dep-3a644805.js');
require('dayjs');
require('../_chunks/dep-5029e827.js');
require('../_chunks/dep-cfb0e78f.js');
require('../_chunks/dep-31fe6b59.js');
require('../_chunks/dep-e2cd1076.js');
require('../_chunks/dep-333f1d82.js');
require('../_chunks/dep-142e416b.js');
require('../_chunks/dep-1a60658f.js');
require('../_chunks/dep-6aef49c4.js');
require('../_chunks/dep-9141aa78.js');
require('../_chunks/dep-2c83a65b.js');
require('../_chunks/dep-d57d3ed5.js');
require('../_chunks/dep-8aaa430c.js');
require('../_chunks/dep-54b872a8.js');
require('../_chunks/dep-402efc35.js');
require('../_chunks/dep-2793a292.js');
require('../_chunks/dep-9bef960e.js');
require('../hooks/render-tnode.js');
require('../_chunks/dep-0484d708.js');
require('../_chunks/dep-45a683b0.js');
require('../_chunks/dep-f01c346c.js');
require('../_chunks/dep-9289591a.js');
require('../_chunks/dep-f4556ad8.js');
require('../_chunks/dep-b4897936.js');
require('../_chunks/dep-db2c642e.js');
require('../_chunks/dep-86f56bd7.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _typeof__default = /*#__PURE__*/_interopDefaultLegacy(_typeof);
var _slicedToArray__default = /*#__PURE__*/_interopDefaultLegacy(_slicedToArray);
var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

var prefix = config["default"].prefix;
var _Textarea = vue.defineComponent({
  name: "".concat(prefix, "-textarea"),
  props: textarea_props["default"],
  setup: function setup(props2, context) {
    var renderTNodeJSX = hooks_tnode.useTNodeJSX();
    var isDisabled = form_hooks.useFormDisabled();
    var formItem = vue.inject(form_const.FormItemInjectionKey, void 0);
    var textareaClass = hooks_useClass.usePrefixClass("textarea");
    var textareaClasses = vue.computed(function () {
      return ["".concat(textareaClass.value), _defineProperty__default["default"](_defineProperty__default["default"]({}, "".concat(textareaClass.value, "--layout-").concat(props2.layout), props2.layout), "".concat(textareaClass.value, "--border"), props2.bordered)];
    });
    var textareaInnerClasses = vue.computed(function () {
      return ["".concat(textareaClass.value, "__wrapper-inner"), _defineProperty__default["default"](_defineProperty__default["default"]({}, "".concat(textareaClass.value, "--disabled"), isDisabled.value), "".concat(textareaClass.value, "--readonly"), props2.readonly)];
    });
    var textareaRef = vue.ref();
    var textareaStyle = vue.ref();
    var _toRefs = vue.toRefs(props2),
      value = _toRefs.value,
      modelValue = _toRefs.modelValue;
    var _useVModel = hooks_useVModel["default"](value, modelValue, props2.defaultValue, props2.onChange),
      _useVModel2 = _slicedToArray__default["default"](_useVModel, 2),
      innerValue = _useVModel2[0],
      setInnerValue = _useVModel2[1];
    var limitParams = vue.computed(function () {
      return {
        value: [void 0, null].includes(innerValue.value) ? void 0 : String(innerValue.value),
        maxlength: Number(props2.maxlength),
        maxcharacter: props2.maxcharacter,
        allowInputOverMax: props2.allowInputOverMax
      };
    });
    var _useLengthLimit = hooks_useLengthLimit["default"](limitParams),
      limitNumber = _useLengthLimit.limitNumber,
      getValueByLimitNumber = _useLengthLimit.getValueByLimitNumber;
    var setInputValue = function setInputValue() {
      var v = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";
      var input = textareaRef.value;
      var sV = String(v);
      if (!input) {
        return;
      }
      if (input.value !== sV) {
        input.value = sV;
      }
    };
    var adjustTextareaHeight = function adjustTextareaHeight() {
      if (props2.autosize === true) {
        textareaStyle.value = _common_js_utils_calcTextareaHeight["default"](textareaRef.value);
      } else if (props2.autosize === false) {
        textareaStyle.value = _common_js_utils_calcTextareaHeight["default"](textareaRef.value, 1, 1);
      } else if (_typeof__default["default"](props2.autosize) === "object") {
        var _props2$autosize = props2.autosize,
          minRows = _props2$autosize.minRows,
          maxRows = _props2$autosize.maxRows;
        textareaStyle.value = _common_js_utils_calcTextareaHeight["default"](textareaRef.value, minRows, maxRows);
      } else if (context.attrs.rows) {
        textareaStyle.value = {
          height: "auto",
          minHeight: "auto"
        };
      }
    };
    var handleInput = function handleInput(e) {
      if (e instanceof InputEvent) {
        if (e.isComposing || e.inputType === "insertCompositionText") return;
      }
      textareaValueChangeHandle();
    };
    var textareaValueChangeHandle = function textareaValueChangeHandle() {
      var textarea = textareaRef.value;
      setInnerValue(getValueByLimitNumber(textarea.value));
      vue.nextTick(function () {
        return setInputValue(innerValue.value);
      });
      adjustTextareaHeight();
    };
    var handleCompositionend = function handleCompositionend(e) {
      textareaValueChangeHandle();
    };
    var handleFocus = function handleFocus(e) {
      var _props2$onFocus;
      (_props2$onFocus = props2.onFocus) === null || _props2$onFocus === void 0 || _props2$onFocus.call(props2, innerValue.value, {
        e: e
      });
    };
    var handleBlur = function handleBlur(e) {
      var _props2$onBlur;
      formItem === null || formItem === void 0 || formItem.handleBlur();
      (_props2$onBlur = props2.onBlur) === null || _props2$onBlur === void 0 || _props2$onBlur.call(props2, innerValue.value, {
        e: e
      });
    };
    vue.onMounted(function () {
      if (props2.autofocus) {
        var _textareaRef$value;
        (_textareaRef$value = textareaRef.value) === null || _textareaRef$value === void 0 || _textareaRef$value.focus();
      }
      textareaValueChangeHandle();
      adjustTextareaHeight();
    });
    vue.watch(innerValue, function () {
      vue.nextTick(function () {
        adjustTextareaHeight();
      });
    });
    vue.watch(function () {
      return props2.autosize;
    }, function () {
      adjustTextareaHeight();
    });
    return function () {
      var renaderLabel = function renaderLabel() {
        var label = renderTNodeJSX("label");
        return label ? vue.createVNode("div", {
          "class": "".concat(textareaClass.value, "__label")
        }, [label]) : null;
      };
      var readerIndicator = function readerIndicator() {
        var isShowIndicator = props2.indicator && (props2.maxcharacter || props2.maxlength);
        if (!isShowIndicator) {
          return null;
        }
        return vue.createVNode("div", {
          "class": "".concat(textareaClass.value, "__indicator")
        }, [" ", limitNumber.value]);
      };
      var textareaAttrs = {
        ref: textareaRef,
        class: textareaInnerClasses.value,
        style: textareaStyle.value,
        value: innerValue.value,
        name: props2.name,
        disabled: isDisabled.value,
        placeholder: props2.placeholder,
        readonly: props2.readonly,
        onFocus: handleFocus,
        onBlur: handleBlur,
        onInput: handleInput,
        onCompositionend: handleCompositionend
      };
      return vue.createVNode("div", {
        "class": textareaClasses.value
      }, [renaderLabel(), vue.createVNode("div", {
        "class": "".concat(textareaClass.value, "__wrapper")
      }, [vue.createVNode("textarea", textareaAttrs, null), readerIndicator()])]);
    };
  }
});

exports["default"] = _Textarea;
//# sourceMappingURL=textarea.js.map
