/**
 * tdesign v1.8.5
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { defineComponent, computed, ref, onMounted, onBeforeUnmount, createVNode, Fragment } from 'vue';
import config from '../config.mjs';
import CountDownProps from './props.mjs';
import { useCountDown } from '../shared/useCountDown/index.mjs';
import { useTNodeJSX } from '../hooks/tnode.mjs';
import { usePrefixClass } from '../hooks/useClass.mjs';
import '../_chunks/dep-193006a3.mjs';
import '../_chunks/dep-c32fde6f.mjs';
import '../_chunks/dep-3f47bc46.mjs';
import '@vueuse/core';
import '../shared/useCountDown/utils.mjs';
import '../shared/util.mjs';
import '../_chunks/dep-a2ad5b0c.mjs';
import '../_chunks/dep-a75faf43.mjs';
import 'lodash-es';
import '../hooks/render-tnode.mjs';
import '../config-provider/useConfig.mjs';
import '../_chunks/dep-053cb48c.mjs';
import '../config-provider/context.mjs';
import '../_common/js/global-config/mobile/default-config.mjs';
import '../_common/js/global-config/mobile/locale/zh_CN.mjs';
import '../_chunks/dep-03e8deb3.mjs';
import '../_chunks/dep-f4f4cd7d.mjs';
import '../_chunks/dep-39376bb1.mjs';
import '../config-provider/type.mjs';

var prefix = config.prefix;
var _CountDown = defineComponent({
  name: "".concat(prefix, "-count-down"),
  props: CountDownProps,
  setup: function setup(props) {
    var renderTNodeJSX = useTNodeJSX();
    var countDownClass = usePrefixClass("count-down");
    var countDownClasses = computed(function () {
      return [countDownClass.value, "".concat(countDownClass.value, "--").concat(props.theme), "".concat(countDownClass.value, "--").concat(props.size)];
    });
    var visibility = ref(true);
    var visibilitychangeListener = function visibilitychangeListener() {
      visibility.value = !document.hidden;
    };
    onMounted(function () {
      document.addEventListener("visibilitychange", visibilitychangeListener, false);
    });
    onBeforeUnmount(function () {
      document.removeEventListener("visibilitychange", visibilitychangeListener, false);
    });
    var _useCountDown = useCountDown(props, visibility),
      showTimes = _useCountDown.showTimes;
    return function () {
      var renderContent = function renderContent() {
        var content = renderTNodeJSX("content");
        if (props.content !== "default" && content) {
          return content;
        }
        return showTimes.map(function (item) {
          return createVNode(Fragment, null, [createVNode("span", {
            "class": "".concat(countDownClass.value, "__item")
          }, [item.value]), item.mark && createVNode("span", {
            "class": ["".concat(countDownClass.value, "__split"), "".concat(countDownClass.value, "__split--").concat(props.splitWithUnit ? "text" : "dot")]
          }, [item.mark])]);
        });
      };
      return createVNode("div", {
        "class": countDownClasses.value
      }, [renderContent()]);
    };
  }
});

export { _CountDown as default };
//# sourceMappingURL=count-down.mjs.map
