/**
 * tdesign v1.8.5
 * (c) 2025 TDesign Group
 * @license MIT
 */

import { defineComponent, ref, onMounted, nextTick, onUpdated, createVNode } from 'vue';
import circleAdapter from '../../_common/js/loading/circle-adapter.mjs';
import config from '../../config.mjs';
import { usePrefixClass } from '../../hooks/useClass.mjs';
import '../../_chunks/dep-053cb48c.mjs';
import '../../_chunks/dep-c32fde6f.mjs';
import '../../_common/js/utils/setStyle.mjs';
import '../../_common/js/utils/helper.mjs';
import '../../_chunks/dep-6be01994.mjs';
import '../../_chunks/dep-a75faf43.mjs';
import '../../_chunks/dep-10e7ac6e.mjs';
import '../../_chunks/dep-a2ad5b0c.mjs';
import 'lodash-es';
import '../../config-provider/useConfig.mjs';
import '../../config-provider/context.mjs';
import '../../_common/js/global-config/mobile/default-config.mjs';
import '../../_common/js/global-config/mobile/locale/zh_CN.mjs';
import '../../_chunks/dep-03e8deb3.mjs';
import '../../_chunks/dep-3f47bc46.mjs';
import '../../_chunks/dep-f4f4cd7d.mjs';
import '../../_chunks/dep-39376bb1.mjs';
import '../../config-provider/type.mjs';

var prefix = config.prefix;
var TGradientIcon = defineComponent({
  name: "".concat(prefix, "-gradient"),
  props: {
    style: Object
  },
  setup: function setup(props) {
    var gradientClass = usePrefixClass("loading__gradient");
    var classes = [gradientClass.value, "".concat(prefix, "-icon-loading")];
    var circle = ref();
    var updateColor = function updateColor() {
      var circleElem = circle.value;
      circleAdapter(circleElem);
    };
    onMounted(function () {
      nextTick(function () {
        updateColor();
      });
    });
    onUpdated(function () {
      updateColor();
    });
    return function () {
      return createVNode("svg", {
        "style": props.style,
        "class": classes,
        "viewBox": "0 0 12 12",
        "version": "1.1",
        "width": "1em",
        "height": "1em",
        "xmlns": "http://www.w3.org/2000/svg"
      }, [createVNode("foreignObject", {
        "x": "0",
        "y": "0",
        "width": "12",
        "height": "12"
      }, [createVNode("div", {
        "ref": circle,
        "class": "".concat(gradientClass.value, "-conic")
      }, null)])]);
    };
  }
});

export { TGradientIcon as default };
//# sourceMappingURL=gradient.mjs.map
